@@ -4,12 +4,14 @@ import subprocess
 import typer
 import integrate_ai.sdk as sdk
 import integrate_ai.client as client
+import integrate_ai.server as server
 from rich import print as rprint
 
 app = typer.Typer(no_args_is_help=True)
 
 app.add_typer(sdk.app, name="sdk")
 app.add_typer(client.app, name="client")
+app.add_typer(server.app, name="server")
 
 package = "integrate-ai"
 
