@@ -24,7 +24,7 @@ class DockerClient:
     This class performs various docker operations such as login, pull, rmi, etc.
     """
 
-    def __init__(self, token: Optional[str] = None, gpu: bool = False):
+    def __init__(self, token: Optional[str] = None, gpu: bool = False, image_name: str = "fl-client"):
         """Initialize.
 
         Args:
@@ -39,6 +39,7 @@ class DockerClient:
         self.repo: str = ""
         self.ecr_token: str = ""
         self.ecr_username: str = ""
+        self.image_name = image_name
         self.docker_image_name: str = self.get_repo_name()
 
     def login(self) -> Optional[Dict]:
@@ -70,17 +71,22 @@ class DockerClient:
     def get_repo_name(self) -> str:
         """Retrieves the client image name to pull.
 
-        If `IAI_ALT_DOCKER_IMAGE_NAME` environment variable is set, this can be changed to
-          a different image name for internal use or debugging.
+        If `IAI_ALT_DOCKER_IMAGE_NAME` or `IAI_ALT_SERVER_IMAGE_NAME` environment variable is set,
+        this can be changed to a different image name for internal use or debugging.
 
         Note: If a custom image name is set, it should have at least one forward slash.
 
         Returns:
             name (str): name of the docker image to retrieve.
         """
-        name = os.environ.get("IAI_ALT_DOCKER_IMAGE_NAME")
+        if self.image_name == "fl-client":
+            name = os.environ.get("IAI_ALT_DOCKER_IMAGE_NAME")
+        else:
+            name = os.environ.get("IAI_ALT_SERVER_IMAGE_NAME")
+
+        base_path = "919740802015.dkr.ecr.ca-central-1.amazonaws.com/edge/"
         if not name:
-            name = "919740802015.dkr.ecr.ca-central-1.amazonaws.com/edge/fl-client"
+            name = base_path + self.image_name
         return name
 
     def _auth_dict(self) -> Dict[str, str]:
@@ -199,12 +205,14 @@ class DockerClient:
             latest_version (str): latest client image version number available in repo."""
 
         available_versions = self.get_versions()
-
-        filtered_versions = [
-            version
-            for version in available_versions
-            if (self.gpu and "-cpu" not in version) or (not self.gpu and "-cpu" in version)
-        ]
+        if self.image_name == "fl-client":
+            filtered_versions = [
+                version
+                for version in available_versions
+                if (self.gpu and "-cpu" not in version) or (not self.gpu and "-cpu" in version)
+            ]
+        else:
+            filtered_versions = available_versions
         return sorted(filtered_versions, key=LooseVersion, reverse=True)[0]
 
     def run(self, image: str, detach: bool, options: Dict[str, Any]) -> Optional[Dict]:
